#!/bin/bash

VERSION='Chrooting package by Martin List-Petersen <martin@list-petersen.dk>'
GROUPCOUNT=`cat /etc/group | grep chroot | wc -l`
SUDOLINE=`grep "%chroot ALL= NOPASSWD: /usr/sbin/chroot *" /etc/sudoers | wc -l`

if let "$GROUPCOUNT == 0"
	then
		echo ""
		echo $VERSION
		echo ""
		echo "Group chroot doesn't exist. Please create that first !"
		echo ""
		exit 1
	fi

if [ ! -x /usr/bin/sudo ]; then
	echo ""
	echo $VERSION
	echo ""
	echo "sudo is not installed. Please install that first !"
	echo ""
	exit 1
fi

if let "$SUDOLINE == 0"
	then
		echo ""
		echo $VERSION
		echo ""
		echo "sudo is not configured correct. Please add the following line to sudoers:"
		echo "%chroot ALL= NOPASSWD: /usr/sbin/chroot *"
		echo ""
		exit 1
	fi

GROUP=`cat /etc/group | grep chroot | awk -F ':' '{print $3;}'`
GROUPCHROOT=`cat /home/chroot-template/etc/group | grep chroot | awk -F ':' '{print $3;}'`

if let "$GROUP == $GROUPCHROOT"
	then
		echo -n ""
	else
		echo ""
		echo $VERSION
		echo ""
		echo "gid for group 'chroot' is not the same in"
		echo "/etc/group and /home/chroot-template/etc/group"
		echo ""
		echo "fix that please !"
		echo ""
		exit 1
	fi

if [ -n "$1" ]; 
	then
		USERLINE=`grep "$1" /etc/passwd | wc -l`
		if let "$USERLINE == 0"
			then
				#
				# add chrooted user
				#
				useradd -g chroot -d /tmp -s /usr/local/chroot-shell -p !! $1
				mkdir /home/$1
				cd /home/$1
				mkdir bin
				mkdir dev
				mkdir etc
				mkdir home
				mkdir lib
				mkdir usr
				mkdir usr/lib
				mkdir etc/terminfo
				mkdir etc/terminfo/l
				ln /home/chroot-template/bin/bash bin/bash
				ln /home/chroot-template/bin/bitchx bin/bitchx
				ln -s bitchx bin/BitchX
				ln /home/chroot-template/bin/cat bin/cat
				ln /home/chroot-template/bin/centericq bin/centericq
				ln /home/chroot-template/bin/clear bin/clear
				ln /home/chroot-template/bin/cp bin/cp
				ln /home/chroot-template/bin/dircolors bin/dircolors
				ln /home/chroot-template/bin/du bin/du
				ln /home/chroot-template/bin/joe bin/joe
				ln /home/chroot-template/bin/ln bin/ln
				ln /home/chroot-template/bin/ls bin/ls
				ln /home/chroot-template/bin/mv bin/mv
				ln /home/chroot-template/bin/nslookup bin/nslookup
				ln /home/chroot-template/bin/rm bin/rm
				ln /home/chroot-template/bin/scr-bx bin/scr-bx
				ln /home/chroot-template/bin/ssh bin/ssh
				ln /home/chroot-template/bin/su bin/su
				mknod -m 0666 dev/tty c 5 0
				mknod -m 0644 dev/urandom c 1 9
				cp /home/chroot-template/etc/passwd etc
				echo -n "$1:x:" >> etc/passwd
				echo -n `cat /etc/passwd | grep $1 | sed "s/:/ /g" | awk '{print $3;}'` >> etc/passwd
				echo ":$GROUP::/home:/bin/bash" >> etc/passwd
				ln /home/chroot-template/etc/group etc/group
				ln /home/chroot-template/etc/host.conf etc/host.conf
				ln /home/chroot-template/etc/hosts etc/hosts
				mkdir etc/joe
				ln /home/chroot-template/etc/joe/joerc etc/joerc
				ln /home/chroot-template/etc/nsswitch.conf etc/nsswitch.conf
				ln /home/chroot-template/etc/resolv.conf etc/resolv.conf
				ln /home/chroot-template/etc/terminfo/l/linux etc/terminfo/l/linux
				cp /home/chroot-template/home/.bash_profile home
				cp /home/chroot-template/home/.bashrc home
				chown -R $1 home 
				ln /home/chroot-template/lib/ld-linux.so.2 lib/ld-linux.so.2
				ln /home/chroot-template/lib/libc.so.6 lib/libc.so.6
				ln /home/chroot-template/lib/libcrypt.so.1 lib/libcrypt.so.1
				ln /home/chroot-template/lib/libcrypto.so.0.9.6 lib/libcrypto.so.0.9.6
				ln /home/chroot-template/lib/libdl.so.2 lib/libdl.so.2
				ln /home/chroot-template/lib/libdns.so.5 lib/libdns.so.5
				ln /home/chroot-template/lib/libisc.so.4 lib/libisc.so.4
				ln /home/chroot-template/lib/libm.so.6 lib/libm.so.6
				ln /home/chroot-template/lib/libncurses.so.5 lib/libncurses.so.5
				ln /home/chroot-template/lib/libnsl.so.1 lib/libnsl.so.1
				ln /home/chroot-template/lib/libnss_compat.so.2 lib/libnss_compat.so.2
				ln /home/chroot-template/lib/libnss_dns.so.2 lib/libnss_dns.so.2
				ln /home/chroot-template/lib/libnss_files.so.2 lib/libnss_files.so.2
				ln /home/chroot-template/lib/libpthread.so.0 lib/libpthread.so.0
				ln /home/chroot-template/lib/libresolv.so.2 lib/libresolv.so.2
				ln /home/chroot-template/lib/librt.so.1 lib/librt.so.1
				ln /home/chroot-template/lib/libsigc-1.0.so.0 lib/libsigc-1.0.so.0
				ln /home/chroot-template/lib/libstdc++-libc6.2-2.so.3 lib/libstdc++-libc6.2-2.so.3
				ln /home/chroot-template/lib/libutil.so.1 lib/libutil.so.1
				ln /home/chroot-template/lib/libz.so.1 lib/libz.so.1
				chgrp -R chroot /home/$1
				passwd $1
			else
				echo ""
				echo "User allready exists, so you don't wanna do this !!"
				echo ""
			fi
	else
		echo ""
		echo $VERSION
		echo ""
		echo "Syntax: chroot-create.sh <username>"
		echo ""
		exit 1
	fi 
